==> haskell-lifted-async-0.10.0.2-23-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-lifted-async.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: lifted-async
version: 0.10.0.2
id: lifted-async-0.10.0.2-DNbbwNAPgdD2cCBpqdhlLX
key: lifted-async-0.10.0.2-DNbbwNAPgdD2cCBpqdhlLX
license: BSD-3-Clause
copyright: Copyright (C) 2012-2018 Mitsutoshi Aoe
maintainer: Mitsutoshi Aoe <maoe@foldr.in>
author: Mitsutoshi Aoe
homepage: https://github.com/maoe/lifted-async
synopsis: Run lifted IO operations asynchronously and wait for their results
description:
    This package provides IO operations from @async@ package lifted to any
    instance of '\''MonadBase'\'' or '\''MonadBaseControl'\''.
category: Concurrency
abi: 230478495ca433442b9cc4b8927362b7
exposed: True
exposed-modules:
    Control.Concurrent.Async.Lifted
    Control.Concurrent.Async.Lifted.Safe
import-dirs: /usr/lib/ghc-8.4.3/site-local/lifted-async-0.10.0.2
library-dirs: /usr/lib/ghc-8.4.3/site-local/lifted-async-0.10.0.2
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.4.3/lifted-async-0.10.0.2
hs-libraries: HSlifted-async-0.10.0.2-DNbbwNAPgdD2cCBpqdhlLX
depends:
    base-4.11.1.0 async-2.2.1-B6m2kYywRJu7nicgTBxsJe
    lifted-base-0.2.3.12-ABNDagqjRNeKAahSmpDuYm
    transformers-base-0.4.5.2-AexAWi6e5nx6jQ9Vfwnuts
    monad-control-1.0.2.3-7JzgqOE5QdMK1n6qA1B9zU
    constraints-0.10.1-LsiJjUfK3suAFcfwQSuJNF
abi-depends: base-4.11.1.0=9da3f387598d41928f3ebf8097acf9b3
             async-2.2.1-B6m2kYywRJu7nicgTBxsJe=64d83880768398851ddaf7518afebeee
             lifted-base-0.2.3.12-ABNDagqjRNeKAahSmpDuYm=374119d2b864cbd9349f6daade762c0b
             transformers-base-0.4.5.2-AexAWi6e5nx6jQ9Vfwnuts=429c07af1089832867529f5d7ce0e624
             monad-control-1.0.2.3-7JzgqOE5QdMK1n6qA1B9zU=69e6cbcc316152f03e15a8ee01a3a4a0
             constraints-0.10.1-LsiJjUfK3suAFcfwQSuJNF=0b98aa3109233d859b1cab45d350457c
haddock-interfaces: /usr/share/doc/haskell-lifted-async/html/lifted-async.haddock
haddock-html: /usr/share/doc/haskell-lifted-async/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-lifted-async-0.10.0.2-25-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-lifted-async.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: lifted-async
version: 0.10.0.2
id: lifted-async-0.10.0.2-9JGByj9IOjq9SQ0R7urnn4
key: lifted-async-0.10.0.2-9JGByj9IOjq9SQ0R7urnn4
license: BSD-3-Clause
copyright: Copyright (C) 2012-2018 Mitsutoshi Aoe
maintainer: Mitsutoshi Aoe <maoe@foldr.in>
author: Mitsutoshi Aoe
homepage: https://github.com/maoe/lifted-async
synopsis: Run lifted IO operations asynchronously and wait for their results
description:
    This package provides IO operations from @async@ package lifted to any
    instance of '\''MonadBase'\'' or '\''MonadBaseControl'\''.
category: Concurrency
abi: 7d300eff84c9f8a7b90bc0997adc9921
exposed: True
exposed-modules:
    Control.Concurrent.Async.Lifted
    Control.Concurrent.Async.Lifted.Safe
import-dirs: /usr/lib/ghc-8.4.3/site-local/lifted-async-0.10.0.2
library-dirs: /usr/lib/ghc-8.4.3/site-local/lifted-async-0.10.0.2
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.4.3/lifted-async-0.10.0.2
hs-libraries: HSlifted-async-0.10.0.2-9JGByj9IOjq9SQ0R7urnn4
depends:
    base-4.11.1.0 async-2.2.1-B6m2kYywRJu7nicgTBxsJe
    lifted-base-0.2.3.12-37d8j6emaIGEEOTqMcU4EA
    transformers-base-0.4.5.2-EvdLB4rIPwW4Mi0YtbCZsZ
    monad-control-1.0.2.3-8qJgo7g8lzF2BtkxCSCnkI
    constraints-0.10.1-EfLG9Mns1yhDvwjl5KzwlL
abi-depends: base-4.11.1.0=9da3f387598d41928f3ebf8097acf9b3
             async-2.2.1-B6m2kYywRJu7nicgTBxsJe=64d83880768398851ddaf7518afebeee
             lifted-base-0.2.3.12-37d8j6emaIGEEOTqMcU4EA=0c5cdee63bc2bad056833f7f97f82cf8
             transformers-base-0.4.5.2-EvdLB4rIPwW4Mi0YtbCZsZ=9b46c0c542bc8ac21f832a06a7f8e9d2
             monad-control-1.0.2.3-8qJgo7g8lzF2BtkxCSCnkI=20a8eb22fe1aed2b5899ee3d85a0cb2b
             constraints-0.10.1-EfLG9Mns1yhDvwjl5KzwlL=5e7e8e915c1f5c731c96015239fc9ba2
haddock-interfaces: /usr/share/doc/haskell-lifted-async/html/lifted-async.haddock
haddock-html: /usr/share/doc/haskell-lifted-async/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
